Crate reifydb_remote_proxy

Crate reifydb_remote_proxy 

Structs

RemoteSubscription
An active remote subscription, wrapping the underlying gRPC connection.

Enums

RemoteSubscriptionError
Error returned when connecting to a remote subscription fails.

Functions

connect_remote
Connect to a remote node and create a subscription.
proxy_remote
Proxy raw payloads from a remote subscription to a local channel.
proxy_remote_to_sink
Proxy raw payloads from a remote subscription into a caller-supplied sink closure.